[java-idp-plugin-webauthn] branch main updated: Rename storage service credential repository to WebAuthn cred repo

Phil Smart philip.smart at jisc.ac.uk
Fri Jul 19 10:09:52 UTC 2024


This is an automated email from the git hooks/post-receive script.

philsmart pushed a commit to branch main
in repository java-idp-plugin-webauthn.

View the commit online:
http://git.shibboleth.net/view/?p=java-idp-plugin-webauthn.git;a=commit;h=3679aaf3c44d5f4a2ae8c9274d7b0016d259e2e3

The following commit(s) were added to refs/heads/main by this push:
     new 3679aaf  Rename storage service credential repository to WebAuthn cred repo
3679aaf is described below

commit 3679aaf3c44d5f4a2ae8c9274d7b0016d259e2e3
Author: Phil Smart <philip.smart at jisc.ac.uk>
AuthorDate: Fri Jul 19 11:09:49 2024 +0100

    Rename storage service credential repository to WebAuthn cred repo
    
     - It does not need to be based on the storage service even if the
    default implementation is, but it could be anything. So make the name
    more generic.
---
 ...edentialRepository.java => WebAuthnCredentialRepository.java} | 9 +++------
 .../idp/plugin/authn/webauthn/admin/impl/AddUserId.java          | 4 ++--
 .../webauthn/admin/impl/AdminDeletePublicKeyCredential.java      | 4 ++--
 .../authn/webauthn/admin/impl/DeletePublicKeyCredential.java     | 4 ++--
 .../authn/webauthn/admin/impl/LookupCredentialsForUser.java      | 4 ++--
 .../authn/webauthn/admin/impl/StorePublicKeyCredential.java      | 4 ++--
 .../idp/plugin/authn/webauthn/impl/AbstractWebAuthnAction.java   | 8 ++++----
 .../plugin/authn/webauthn/impl/LookupRegisteredCredentials.java  | 4 ++--
 .../webauthn/impl/LookupRegisteredCredentialsFromUserHandle.java | 4 ++--
 .../plugin/authn/webauthn/impl/ValidateWebAuthnAssertion.java    | 6 +++---
 .../storage/impl/IdPStorageServiceCredentialRespository.java     | 4 ++--
 .../idp/plugin/authn/webauthn/impl/AbstractWebAuthnTest.java     | 4 ++--
 .../authn/webauthn/storage/impl/InMemoryRegistrationStorage.java | 4 ++--
 13 files changed, 30 insertions(+), 33 deletions(-)

diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/AddUserId.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/AddUserId.java
index 468b0ae..1dbb634 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/AddUserId.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/AddUserId.java
@@ -32,7 +32,7 @@ import com.yubico.webauthn.data.ByteArray;
 import net.shibboleth.idp.plugin.authn.webauthn.admin.WebAuthnRegistrationEventIds;
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnRegistrationContext;
 import net.shibboleth.idp.plugin.authn.webauthn.impl.AbstractWebAuthnAction;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NonnullBeforeExec;
 import net.shibboleth.shared.codec.Base64Support;
@@ -70,7 +70,7 @@ public class AddUserId extends AbstractWebAuthnAction<WebAuthnRegistrationContex
     @NonnullBeforeExec private String username;
     
     /** The credential repository to use.*/
-    @NonnullAfterInit private StorageServiceCredentialRepository repository;
+    @NonnullAfterInit private WebAuthnCredentialRepository repository;
     
     /** {@inheritDoc} */
     @Override
diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/AdminDeletePublicKeyCredential.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/AdminDeletePublicKeyCredential.java
index a97a09b..7af5e4c 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/AdminDeletePublicKeyCredential.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/AdminDeletePublicKeyCredential.java
@@ -29,7 +29,7 @@ import com.yubico.webauthn.data.ByteArray;
 import net.shibboleth.idp.plugin.authn.webauthn.admin.WebAuthnRegistrationEventIds;
 import net.shibboleth.idp.plugin.authn.webauthn.audit.impl.AbstractWebAuthnAuditingAction;
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnManagementContext;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.codec.Base64Support;
 import net.shibboleth.shared.codec.EncodingException;
@@ -52,7 +52,7 @@ public class AdminDeletePublicKeyCredential extends AbstractWebAuthnAuditingActi
     private final Logger log = LoggerFactory.getLogger(AdminDeletePublicKeyCredential.class); 
     
     /** The credential repository to use.*/
-    @NonnullAfterInit private StorageServiceCredentialRepository repository;
+    @NonnullAfterInit private WebAuthnCredentialRepository repository;
     
     /** Constructor.*/
     public AdminDeletePublicKeyCredential() {
diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/DeletePublicKeyCredential.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/DeletePublicKeyCredential.java
index 95cbd16..fd4a857 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/DeletePublicKeyCredential.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/DeletePublicKeyCredential.java
@@ -32,7 +32,7 @@ import net.shibboleth.idp.plugin.authn.webauthn.admin.WebAuthnRegistrationEventI
 import net.shibboleth.idp.plugin.authn.webauthn.audit.impl.AbstractWebAuthnAuditingAction;
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnRegistrationContext;
 import net.shibboleth.idp.plugin.authn.webauthn.storage.CredentialRegistration;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.component.ComponentInitializationException;
 import net.shibboleth.shared.primitive.LoggerFactory;
@@ -51,7 +51,7 @@ public class DeletePublicKeyCredential extends AbstractWebAuthnAuditingAction<We
     private final Logger log = LoggerFactory.getLogger(DeletePublicKeyCredential.class);  
     
     /** The credential repository to use.*/
-    @NonnullAfterInit private StorageServiceCredentialRepository repository;
+    @NonnullAfterInit private WebAuthnCredentialRepository repository;
     
     /** {@inheritDoc} */
     @Override
diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/LookupCredentialsForUser.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/LookupCredentialsForUser.java
index 0b2942e..cfd5273 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/LookupCredentialsForUser.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/LookupCredentialsForUser.java
@@ -26,7 +26,7 @@ import net.shibboleth.idp.authn.AuthnEventIds;
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnManagementContext;
 import net.shibboleth.idp.plugin.authn.webauthn.impl.AbstractWebAuthnAction;
 import net.shibboleth.idp.plugin.authn.webauthn.storage.CredentialRegistration;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.collection.CollectionSupport;
 import net.shibboleth.shared.component.ComponentInitializationException;
@@ -48,7 +48,7 @@ public class LookupCredentialsForUser extends AbstractWebAuthnAction<WebAuthnMan
     private final Logger log = LoggerFactory.getLogger(LookupCredentialsForUser.class); 
     
     /** The credential repository to use.*/
-    @NonnullAfterInit private StorageServiceCredentialRepository repository;
+    @NonnullAfterInit private WebAuthnCredentialRepository repository;
     
     /** {@inheritDoc} */
     @Override
diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/StorePublicKeyCredential.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/StorePublicKeyCredential.java
index 004ffc7..a2a7ef1 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/StorePublicKeyCredential.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/admin/impl/StorePublicKeyCredential.java
@@ -41,7 +41,7 @@ import net.shibboleth.idp.plugin.authn.webauthn.admin.WebAuthnRegistrationEventI
 import net.shibboleth.idp.plugin.authn.webauthn.audit.impl.AbstractWebAuthnAuditingAction;
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnRegistrationContext;
 import net.shibboleth.idp.plugin.authn.webauthn.storage.CredentialRegistration;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NonnullElements;
 import net.shibboleth.shared.annotation.constraint.NotLive;
@@ -68,7 +68,7 @@ public class StorePublicKeyCredential extends AbstractWebAuthnAuditingAction<Web
     @Nonnull private final Logger log = LoggerFactory.getLogger(StorePublicKeyCredential.class);   
     
     /** The credential repository to use.*/
-    @NonnullAfterInit private StorageServiceCredentialRepository repository;
+    @NonnullAfterInit private WebAuthnCredentialRepository repository;
     
     /** {@inheritDoc} */
     @Override
diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/AbstractWebAuthnAction.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/AbstractWebAuthnAction.java
index 95d73d2..7e19e29 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/AbstractWebAuthnAction.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/AbstractWebAuthnAction.java
@@ -29,7 +29,7 @@ import com.yubico.fido.metadata.FidoMetadataService;
 import net.shibboleth.idp.authn.AuthnEventIds;
 import net.shibboleth.idp.plugin.authn.webauthn.client.WebAuthnAuthenticationClient;
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnAuthenticationContext;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.idp.profile.AbstractProfileAction;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NonnullBeforeExec;
@@ -67,7 +67,7 @@ public class AbstractWebAuthnAction<T> extends AbstractProfileAction {
     @NonnullAfterInit private WebAuthnAuthenticationClient webAuthnClient;
     
     /** The credential repository to store valid credentials in.*/
-    @Nullable private StorageServiceCredentialRepository credentialRepository;
+    @Nullable private WebAuthnCredentialRepository credentialRepository;
     
     /** Optional FIDO metadata service resolver.*/ 
     @Nullable private FidoMetadataService fidoMetadataService;  
@@ -133,7 +133,7 @@ public class AbstractWebAuthnAction<T> extends AbstractProfileAction {
      *  
      * @param repository The respository to set.
      */
-    public void setCredentialRepository(@Nonnull final StorageServiceCredentialRepository repository) {
+    public void setCredentialRepository(@Nonnull final WebAuthnCredentialRepository repository) {
         checkSetterPreconditions();
         credentialRepository = Constraint.isNotNull(repository, "Credential respository can not be null");
     }
@@ -143,7 +143,7 @@ public class AbstractWebAuthnAction<T> extends AbstractProfileAction {
      * 
      * @return the credential repository.
      */
-    @Nullable protected StorageServiceCredentialRepository getCredentialRepository() {
+    @Nullable protected WebAuthnCredentialRepository getCredentialRepository() {
         return credentialRepository;
     }
     
diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/LookupRegisteredCredentials.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/LookupRegisteredCredentials.java
index 16ba7d5..d721874 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/LookupRegisteredCredentials.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/LookupRegisteredCredentials.java
@@ -33,7 +33,7 @@ import net.shibboleth.idp.authn.context.AuthenticationContext;
 import net.shibboleth.idp.plugin.authn.webauthn.authn.WebAuthnAuthenticationEventIds;
 import net.shibboleth.idp.plugin.authn.webauthn.context.BaseWebAuthnContext;
 import net.shibboleth.idp.plugin.authn.webauthn.storage.CredentialRegistration;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NotEmpty;
 import net.shibboleth.shared.component.ComponentInitializationException;
@@ -67,7 +67,7 @@ public class LookupRegisteredCredentials extends AbstractWebAuthnAction<BaseWebA
     @Nonnull @NotEmpty private String noCredentialsEventId;
     
     /** The credential repository to use.*/
-    @NonnullAfterInit private StorageServiceCredentialRepository repository;
+    @NonnullAfterInit private WebAuthnCredentialRepository repository;
     
     /** {@inheritDoc} */
     @Override
diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/LookupRegisteredCredentialsFromUserHandle.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/LookupRegisteredCredentialsFromUserHandle.java
index d739e5e..7448c84 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/LookupRegisteredCredentialsFromUserHandle.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/LookupRegisteredCredentialsFromUserHandle.java
@@ -36,7 +36,7 @@ import net.shibboleth.idp.authn.context.AuthenticationContext;
 import net.shibboleth.idp.plugin.authn.webauthn.authn.WebAuthnAuthenticationEventIds;
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnAuthenticationContext;
 import net.shibboleth.idp.plugin.authn.webauthn.storage.CredentialRegistration;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NotEmpty;
 import net.shibboleth.shared.component.ComponentInitializationException;
@@ -71,7 +71,7 @@ public class LookupRegisteredCredentialsFromUserHandle extends AbstractWebAuthnA
     @Nonnull @NotEmpty private String noCredentialsEventId;
     
     /** The credential repository to use.*/
-    @NonnullAfterInit private StorageServiceCredentialRepository repository;
+    @NonnullAfterInit private WebAuthnCredentialRepository repository;
     
     /** {@inheritDoc} */
     @Override
diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/ValidateWebAuthnAssertion.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/ValidateWebAuthnAssertion.java
index 82991ff..723d5e7 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/ValidateWebAuthnAssertion.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/impl/ValidateWebAuthnAssertion.java
@@ -26,7 +26,7 @@ import net.shibboleth.idp.plugin.authn.webauthn.client.WebAuthnAuthenticationCli
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnAuthenticationContext;
 import net.shibboleth.idp.plugin.authn.webauthn.exception.AssertionFailureException;
 import net.shibboleth.idp.plugin.authn.webauthn.principal.WebAuthnUserIdPrinicpal;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NonnullBeforeExec;
 import net.shibboleth.shared.component.ComponentInitializationException;
@@ -59,7 +59,7 @@ public class ValidateWebAuthnAssertion extends AbstractAuditingValidationAction
     @NonnullAfterInit private WebAuthnAuthenticationClient webAuthnClient;  
     
     /** The credential repository to store valid credentials in.*/
-    @NonnullAfterInit private StorageServiceCredentialRepository credentialRepository;
+    @NonnullAfterInit private WebAuthnCredentialRepository credentialRepository;
     
     /** The options used to create the authentication request.*/
     @NonnullBeforeExec private PublicKeyCredentialRequestOptions publicKeyCredentialRequestOptions;
@@ -95,7 +95,7 @@ public class ValidateWebAuthnAssertion extends AbstractAuditingValidationAction
      *  
      * @param repository The repository to set.
      */
-    public void setCredentialRepository(@Nonnull final StorageServiceCredentialRepository repository) {
+    public void setCredentialRepository(@Nonnull final WebAuthnCredentialRepository repository) {
         checkSetterPreconditions();
         credentialRepository = Constraint.isNotNull(repository, "Credential respository can not be null");
     }    
diff --git a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/impl/IdPStorageServiceCredentialRespository.java b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/impl/IdPStorageServiceCredentialRespository.java
index 2df3481..7ce0a56 100644
--- a/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/impl/IdPStorageServiceCredentialRespository.java
+++ b/webauthn-impl/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/impl/IdPStorageServiceCredentialRespository.java
@@ -45,7 +45,7 @@ import com.yubico.webauthn.data.PublicKeyCredentialDescriptor;
 
 import net.shibboleth.idp.plugin.authn.webauthn.exception.CredentialRepositoryException;
 import net.shibboleth.idp.plugin.authn.webauthn.storage.CredentialRegistration;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.annotation.constraint.NonnullAfterInit;
 import net.shibboleth.shared.annotation.constraint.NotEmpty;
 import net.shibboleth.shared.annotation.constraint.NotLive;
@@ -70,7 +70,7 @@ import net.shibboleth.shared.logic.ConstraintViolationException;
  */
 @ThreadSafeAfterInit
 public class IdPStorageServiceCredentialRespository extends AbstractIdentifiableInitializableComponent
-            implements StorageServiceCredentialRepository {
+            implements WebAuthnCredentialRepository {
     
     /** Class logger.*/
     private static final Logger log = LoggerFactory.getLogger(IdPStorageServiceCredentialRespository.class);
diff --git a/webauthn-impl/src/test/java/net/shibboleth/idp/plugin/authn/webauthn/impl/AbstractWebAuthnTest.java b/webauthn-impl/src/test/java/net/shibboleth/idp/plugin/authn/webauthn/impl/AbstractWebAuthnTest.java
index 4aa0e56..3268dd3 100644
--- a/webauthn-impl/src/test/java/net/shibboleth/idp/plugin/authn/webauthn/impl/AbstractWebAuthnTest.java
+++ b/webauthn-impl/src/test/java/net/shibboleth/idp/plugin/authn/webauthn/impl/AbstractWebAuthnTest.java
@@ -62,7 +62,7 @@ import net.shibboleth.idp.plugin.authn.webauthn.context.BaseWebAuthnContext;
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnAuthenticationContext;
 import net.shibboleth.idp.plugin.authn.webauthn.context.WebAuthnRegistrationContext;
 import net.shibboleth.idp.plugin.authn.webauthn.storage.CredentialRegistration;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.idp.plugin.authn.webauthn.storage.impl.InMemoryRegistrationStorage;
 import net.shibboleth.idp.plugin.authn.webauthn.storage.impl.MockAuthenticator;
 import net.shibboleth.idp.profile.context.navigate.WebflowRequestContextProfileRequestContextLookup;
@@ -113,7 +113,7 @@ public abstract class AbstractWebAuthnTest {
     protected WebAuthnAuthenticationClient client;
     
     /** A mocked credential repository to use.*/
-    protected StorageServiceCredentialRepository credentialRepo;
+    protected WebAuthnCredentialRepository credentialRepo;
     
     /** The relying party.*/
     protected RelyingParty rp;
diff --git a/webauthn-impl/src/test/java/net/shibboleth/idp/plugin/authn/webauthn/storage/impl/InMemoryRegistrationStorage.java b/webauthn-impl/src/test/java/net/shibboleth/idp/plugin/authn/webauthn/storage/impl/InMemoryRegistrationStorage.java
index 64d6771..6111619 100644
--- a/webauthn-impl/src/test/java/net/shibboleth/idp/plugin/authn/webauthn/storage/impl/InMemoryRegistrationStorage.java
+++ b/webauthn-impl/src/test/java/net/shibboleth/idp/plugin/authn/webauthn/storage/impl/InMemoryRegistrationStorage.java
@@ -45,14 +45,14 @@ import com.yubico.webauthn.data.ByteArray;
 import com.yubico.webauthn.data.PublicKeyCredentialDescriptor;
 
 import net.shibboleth.idp.plugin.authn.webauthn.storage.CredentialRegistration;
-import net.shibboleth.idp.plugin.authn.webauthn.storage.StorageServiceCredentialRepository;
+import net.shibboleth.idp.plugin.authn.webauthn.storage.WebAuthnCredentialRepository;
 import net.shibboleth.shared.collection.CollectionSupport;
 
 /**
  * In memory credential repository to use for testing.
  */
 @SuppressWarnings("null")
-public class InMemoryRegistrationStorage implements StorageServiceCredentialRepository {
+public class InMemoryRegistrationStorage implements WebAuthnCredentialRepository {
 
     private final Cache<String, Set<CredentialRegistration>> storage = CacheBuilder.newBuilder().maximumSize(1000)
             .expireAfterAccess(1, TimeUnit.DAYS).build();

diff --git a/webauthn-api/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/StorageServiceCredentialRepository.java b/webauthn-api/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/WebAuthnCredentialRepository.java
similarity index 92%
rename from webauthn-api/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/StorageServiceCredentialRepository.java
rename to webauthn-api/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/WebAuthnCredentialRepository.java
index ec443d0..61f1bf8 100644
--- a/webauthn-api/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/StorageServiceCredentialRepository.java
+++ b/webauthn-api/src/main/java/net/shibboleth/idp/plugin/authn/webauthn/storage/WebAuthnCredentialRepository.java
@@ -20,8 +20,6 @@ import java.util.Set;
 import javax.annotation.Nonnull;
 import javax.annotation.concurrent.ThreadSafe;
 
-import org.opensaml.storage.StorageService;
-
 import com.yubico.webauthn.CredentialRepository;
 import com.yubico.webauthn.data.ByteArray;
 
@@ -30,14 +28,13 @@ import net.shibboleth.shared.annotation.constraint.NotLive;
 import net.shibboleth.shared.annotation.constraint.Unmodifiable;
 
 /**
  * An extension of the {@link CredentialRepository} interface to support additional read and write operations.
  * 
  * <p>Implementations are intended to work with a {@link StorageService}, although that is not a strict requirement.</p>
  * 
  * <p>Implementations of this interface are required to be thread-safe.</p>
  */
 @ThreadSafe
-public interface StorageServiceCredentialRepository extends CredentialRepository {
+public interface WebAuthnCredentialRepository extends CredentialRepository {
 
     /**
      * Get credential registrations by username.
@@ -30,14 +28,13 @@ import net.shibboleth.shared.annotation.constraint.NotLive;
 
 /**
- * An extension of the {@link CredentialRepository} interface to support additional read and write operations.
- * 
- * <p>Implementations are intended to work with a {@link StorageService}, although that is not a strict requirement.</p>
+ * A WebAuthn credential repository that extends the {@link CredentialRepository} interface to support additional read 
+ * and write operations.
  * 
  * <p>Implementations of this interface are required to be thread-safe.</p>
-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list